.. pydss documentation master file, created by
   sphinx-quickstart on Wed Sep  6 19:53:31 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Lines
------------


.. image:: ./png/lines.png
   :width: 300 px
 

.. code:: python

    "lines":[
             {"bus_j": "Bus_1",  "bus_k": "Bus_2",  "code": "UG1", "m": 200.0}
            ]

where:

* ``"bus_j"``: name of the j bus
* ``"bus_k"``: name of the k bus
* ``"code"``: line code  
* ``"m"``: line length in meters
